jacinle.comm.service\_name\_server
==================================

.. automodule:: jacinle.comm.service_name_server

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      SimpleNameServer
      SimpleNameServerClient
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      get_default_name_server_client
      sns_get
      sns_has
      sns_register
   
   

   
   
   








.. rubric:: Class SimpleNameServer
.. autoclass:: SimpleNameServer
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class SimpleNameServerClient
.. autoclass:: SimpleNameServerClient
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: get_default_name_server_client

.. autofunction:: sns_get

.. autofunction:: sns_has

.. autofunction:: sns_register


